<?php
/*
Plugin Name: Easy Scheduled Posts
Plugin URI: http://thisismyurl.com/plugins/easy-scheduled-posts/
Description: An easy to use WordPress function to add scheduled posts to any theme.
Author: Christopher Ross
Tags: future, upcoming posts, upcoming post, upcoming, draft, Post, scheduled, preview, plugin, post, posts
Author URI: http://thisismyurl.com/
Version: 2.0.1
*/

/**
 * Easy Scheduled Posts core file
 *
 * This file contains all the logic required for the plugin
 *
 * @link		http://wordpress.org/extend/plugins/easy-scheduled-posts/
 *
 * @package 		Easy Scheduled Posts
 * @copyright		Copyright (c) 2008, Chrsitopher Ross
 * @license		http://www.gnu.org/licenses/old-licenses/gpl-2.0.html GNU General Public License, v2 (or newer)
 *
 * @since 		Easy Scheduled Posts 1.0
 */

add_shortcode( 'thisismyurl_easy_scheduled_posts', 'thisismyurl_easy_scheduled_posts' );

function thisismyurl_easy_scheduled_posts( $options = '' ) {
	$ns_options = array(
		"count" => "10",
		"before"  => "<li>",
		"after" => "</li>",
		"show" => true,
		"order" => "desc",
		"link" => false,
		"credit" => false,
	);

	$options = explode( "&", $options );
	foreach ( $options as $option ) {
		$parts = explode( "=", $option );
		$ns_options[$parts[0]] = $parts[1];
	}


	if ( strtolower( $ns_options['order'] ) == "desc" ) {
		$sqlorder = "ORDER BY post_date DESC";
	}
	if ( strtolower( $ns_options['order'] ) == "asc" ) {
		$sqlorder = "ORDER BY post_date ASC";
	}
	if ( strtolower( $ns_options['order'] ) == "rand" ) {
		$sqlorder = "ORDER BY RAND()";
	}

	global $wpdb;
    $posts = $wpdb->get_results("
		SELECT ID, post_title
		FROM $wpdb->posts
		WHERE post_type='post' AND post_status = 'future'
		" . $sqlorder . " LIMIT 0 , " . $ns_options['count']
	);
    foreach ( $posts as $post ) {
        setup_postdata($post);
        $id    = $post->ID;
        $title = $post->post_title;
        $count = $post->comment_count;
        $scheduled .= $ns_options['before'];
		if ( $ns_options['link'] == "true" ) {$scheduled .= '<a href="' . get_permalink($id) . '" title="' . $title . '">';}
		$scheduled .= $title;
		if ( $ns_options['link'] == "true") {$scheduled .= '</a>';}
		$scheduled .= $ns_options['after'];
    }

	if ( $ns_options['credit'] == "true" ) {
		$scheduled .= "<li style='font-size: .5em;'><a href='http://thisismyurl.com/plugins/easy-scheduled-posts/'>Scheduled Post Plugin by Christopher Ross</a></li>";
	}
	
	if ( $ns_options['show'] ) {
		echo $scheduled;
	} else {
		return $scheduled;
	}
}



class thisismyurl_easy_scheduled_posts_widget extends WP_Widget
{
	
	
	function thisismyurl_easy_scheduled_posts_widget(){
		$widget_ops = array('classname' => 'widget_thisismyurl_easy_scheduled_posts', 'description' => __( "Scheduled Posts by Christopher Ross") );
		$control_ops = array('width' => 300, 'height' => 300);
		$this->WP_Widget('thisismyurl_easy_scheduled_posts_widget', __('Scheduled Posts'), $widget_ops, $control_ops);
	}

	function update($new_instance, $old_instance){
		$instance = $old_instance;
		$instance['title'] = strip_tags(stripslashes($new_instance['title']));
		$instance['count'] = strip_tags(stripslashes($new_instance['count']));
		$instance['order'] = strip_tags(stripslashes($new_instance['order']));
		$instance['link'] = strip_tags(stripslashes($new_instance['link']));
		$instance['credit'] = strip_tags(stripslashes($new_instance['credit']));

		return $instance;
	}

	function form($instance){
		$instance = wp_parse_args( (array) $instance, array('title'=>'Scheduled Posts', 'count'=>'5', 'order'=>'desc', 'link'=>'false', 'credit'=>'false') );

		$title = htmlspecialchars($instance['title']);
		$count = htmlspecialchars($instance['count']);
		$order = htmlspecialchars($instance['order']);
		$link = htmlspecialchars($instance['link']);
		$credit = htmlspecialchars($instance['credit']);

		for ($i = 5; $i <= 25; $i=$i+5) {
			$countoption .= "<option value='$i' ";
			if ($count == $i) {$countoption .= "selected";}
			$countoption .= ">$i</option>";
		}
	
		if ($order == "desc") {$orderoption .= "<option value='desc' selected >Descending</option>";} else {$orderoption .= "<option value='desc'>Descending</option>";}
		if ($order == "asc") {$orderoption .= "<option value='asc' selected >Ascending</option>";} else {$orderoption .= "<option value='asc'>Ascending</option>";}


		if ($link == "true") {$linkoption .= "<option value='true' selected >Yes</option>";} else {$linkoption .= "<option value='true'>Yes</option>";}
		if ($link == "false") {$linkoption .= "<option value='false' selected >No</option>";} else {$linkoption .= "<option value='false'>No</option>";}

		if ($credit == "true") {$creditoption .= "<option value='true' selected >Yes</option>";} else {$creditoption .= "<option value='true'>Yes</option>";}
		if ($credit == "false") {$creditoption .= "<option value='false' selected >No</option>";} else {$creditoption .= "<option value='false'>No</option>";}


		# Output the options
		echo '	<p style="text-align:left;"><label for="' . $this->get_field_name('title') . '">' . __('Title:') . '</label><br />
				<input style="width: 300px;" id="' . $this->get_field_id('title') . '" name="' . $this->get_field_name('title') . '" type="text" value="' . $title . '" />
				</p>';
		echo '	<p style="text-align:left;"><label for="' . $this->get_field_name('count') . '">' . __('Count:') . '</label><br />
				<select id="' . $this->get_field_id('count') . '" name="' . $this->get_field_name('count') . '">'.$countoption.'</select>
				</p>';	
		
		echo '	<p style="text-align:left;"><label for="' . $this->get_field_name('order') . '">' . __('Order:') . '</label><br />
				<select id="' . $this->get_field_id('order') . '" name="' . $this->get_field_name('order') . '">'.$orderoption.'</select>
				</p>';
				
		echo '	<p style="text-align:left;"><label for="' . $this->get_field_name('link') . '">' . __('Include Link?') . '</label><br />
				<select id="' . $this->get_field_id('link') . '" name="' . $this->get_field_name('link') . '">'.$linkoption.'</select>
				</p>';
				
		echo '	<p style="text-align:left;"><label for="' . $this->get_field_name('credit') . '">' . __('Include Credit?') . '</label><br />
				<select id="' . $this->get_field_id('credit') . '" name="' . $this->get_field_name('credit') . '">'.$creditoption.'</select>
				</p>';		
	}


	/*  Displays the Widget */
	function widget($args, $instance){
		extract( $args );
		$instance = wp_parse_args( (array) $instance, array('title'=>'Scheduled Posts', 'count'=>'5', 'order'=>'desc', 'link'=>'false', 'credit' => 'false') );

		# Before the widget
		echo $before_widget;
		echo '<h4 class="widgettitle">'.$instance['title'].'</h4>';
		echo '<ul>'.thisismyurl_easy_scheduled_posts('credit='.$instance['credit'].'&link='.$instance['link'].'&count='.$instance['count'].'&order='.$instance['order']).'</ul>';
		echo $after_widget;

	}

}// END class

function thisismyurl_easy_scheduled_posts_widget_Init() {
	register_widget('thisismyurl_easy_scheduled_posts_widget');
}
add_action('widgets_init', 'thisismyurl_easy_scheduled_posts_widget_Init');

?>